local table = require("hp/lang/table")
local class = require("hp/lang/class")
local WidgetManager = require("hp/manager/WidgetManager")

--------------------------------------------------------------------------------
-- テーマを設定するオブジェクトを表すクラスです.<br>
-- 単独では使用せず、必ず継承して使用する事を想定します.
-- @class table
-- @name Widget
--------------------------------------------------------------------------------
local M = class()

--------------------------------------------------------------------------------
-- コンストラクタです.
-- Widgetクラスはこちらを使用すべきです.
--------------------------------------------------------------------------------
function M:init(params)
    self:setPrivate("theme", {})
end

----------------------------------------------------------------
-- ウィジットのテーマを取得します.
----------------------------------------------------------------
function M:getTheme()
    return self:getPrivate("theme")
end

----------------------------------------------------------------
-- ウィジットのテーマを設定します.
----------------------------------------------------------------
function M:setTheme(theme)
    self:setPrivate("theme", theme)
end

----------------------------------------------------------------
-- ウィジットのテーマを上書きします.
----------------------------------------------------------------
function M:overrideTheme(theme)
    return table.deepCopy(theme or {}, self:getTheme())
end

----------------------------------------------------------------
-- ウィジットのテーマ名を返します.
-- デフォルトではないので空です.
-- 継承側で定義する必要があります.
----------------------------------------------------------------
function M:getThemeName()
    return ""
end

--------------------------------------------------------------------------------
-- デフォルトテーマを返します.
--------------------------------------------------------------------------------
function M:getDefaultTheme()
    return WidgetManager:getDefaultThemes()[self:getThemeName()]
end

--------------------------------------------------------------------------------
-- スタイルを設定します.
-- スタイルは、テーマのパラメータです.
--------------------------------------------------------------------------------
function M:setStyle(name, value)
    self:getTheme()[name] = value
end

--------------------------------------------------------------------------------
-- スタイルを返します.
--------------------------------------------------------------------------------
function M:getStyle(name)
    return self:getTheme()[name]
end


return M